@@ -1,25 +1,21 @@
 #!/usr/bin/env python
-import gtk.glade, gtk, gobject, os.path, time, os, sys, re, threading, gtk.gdk, Image, StringIO, pango, string, keyEditor, traceback
+import os.path, time, os, threading
+#import Image
+import gtk.glade, gtk, gtk.gdk
 import recipeManager
 import nutrition.nutrition, nutrition.nutritionGrabberGui
-import exporters.printer as printer
-import prefs, prefsGui, shopgui, reccard, convertGui, fnmatch, tempfile
-import exporters, importers
-import convert, WidgetSaver, version, ratingWidget
-import importers.mastercook_importer as mastercook_importer
+import prefs, prefsGui, shopgui, reccard, convertGui
+import convert, WidgetSaver, ratingWidget
+#import importers.mastercook_importer as mastercook_importer
 import dialog_extras as de
-import treeview_extras as te
-from ImageExtras import get_pixbuf_from_jpg
 from gdebug import *
 from gglobals import *
 from recindex import RecIndex
-import exporters.recipe_emailer as recipe_emailer
 import locale, gettext
 from timer import show_timer
 _ = gettext.gettext
 from defaults import lang as defaults
 
-from zipfile import BadZipfile
 
 if os.name == 'posix':
     # somewhat hackish -- we assume USR ==
@@ -74,6 +70,7 @@ class RecGui (RecIndex):
     calling a recipe as an ingredient or when looking through the "trash". """
 
     def __init__ (self,splash_label=None):
+        import hildon
         # used on imports to make filtering wait until
         # we are all done.
         self.wait_to_filter=False
@@ -83,12 +80,12 @@ class RecGui (RecIndex):
             # some unknown reason
             # apparently some outdated GNOME bindings are
             # missing this.
-            if hasattr(gnome,'program_init'):
-                gnome.program_init(version.appname,version.version)
-            else:
-                debug(
-                    'You appear to have an outdated version of python-gnome bindings: gnome.program_init does not exist.',
-                    0)
+            #if hasattr(gnome,'program_init'):
+            #    gnome.program_init(version.appname,version.version)
+            #else:
+            #    debug(
+            #        'You appear to have an outdated version of python-gnome bindings: gnome.program_init does not exist.',
+            #        0)
         except ImportError:
             pass
         if debug_level > 0:
@@ -101,16 +98,50 @@ class RecGui (RecIndex):
             self.prefs,
             buttons={'clear_remembered_optional_button':lambda *args: self.forget_remembered_optional_ingredients()}
             )
-        self.prefsGui.apply_prefs_dic['recipes_per_page']= lambda p,v: getattr(getattr(self,'rmodel'),
+        self.prefsGui.apply_prefs_dic['recipes_per_page'] = lambda p,v: getattr(getattr(self,'rmodel'),
                                                                                'change_items_per_page')(v)
+
+        def toggleFractions (prefname,use):
+            print 'toggleFractions->',use
+            if use:
+                convert.USE_FRACTIONS = convert.FRACTIONS_NORMAL
+            else:
+                convert.USE_FRACTIONS = convert.FRACTIONS_OFF
+        self.prefsGui.apply_prefs_dic['useFractions'] = toggleFractions
+        if self.prefs.get('useFractions',
+                          defaults.LANG_PROPERTIES['useFractions']
+                          ):
+            convert.USE_FRACTIONS = convert.FRACTIONS_NORMAL
+        else:
+            convert.USE_FRACTIONS = convert.FRACTIONS_OFF
+        
         self.update_splash(_("Loading graphical interface..."))        
         gtk.glade.bindtextdomain('gourmet',DIR)
         gtk.glade.textdomain('gourmet')
         debug("gladebase is: %s"%gladebase,1)
         self.glade = gtk.glade.XML(os.path.join(gladebase,'app.glade'))
         self.pop = self.glade.get_widget('rlmen')
-        self.app = self.glade.get_widget('app')
+        self.app = hildon.Window()
+        self.app.connect('destroy', self.quit)
+        self.app.set_default_size(800, 480)
+        self.app.set_title('Recipe Index')
+        self.app.connect("key-press-event", self.on_key_press)
+        self.app.connect("window-state-event", self.on_window_state_change)
+        self.window_in_fullscreen = False 
+
+        gtkwindow = self.glade.get_widget('app')
+        alignment20 = self.glade.get_widget('alignment20')
+        alignment20.reparent(self.app)
         self.prog = self.glade.get_widget('progressbar')
+		##Hildonize menubar##
+
+        mainMenu = self.glade.get_widget('menubar3')
+        menu = gtk.Menu()
+        for child in mainMenu.get_children():
+            child.reparent(menu)
+        self.app.set_menu(menu)
+        mainMenu.destroy()
+
         # configuration stuff
         # WidgetSaver is our way of remembering the state and position of
         # windows and widgets for the future.
@@ -131,6 +162,7 @@ class RecGui (RecIndex):
                                    self.glade.get_widget('rlShopRecMenu'),
                                    self.glade.get_widget('rlDelRecButton'),
                                    self.glade.get_widget('rlDelRecMenu'),
+                                   self.glade.get_widget('rlBatchEditRecMenu'),
                                    self.glade.get_widget('export_menu_item'),
                                    self.glade.get_widget('email_menu_item'),
                                    self.glade.get_widget('print_menu_item'),
@@ -178,12 +210,14 @@ class RecGui (RecIndex):
             'colPrefs': self.show_preferences,
             'unitConverter': self.showConverter,
             'ingKeyEditor': self.showKeyEditor,
+            'valueEditor': self.showValueEditor,
             'print':self.print_recs,
             'email':self.email_recs,
             #'email_prefs':self.email_prefs,
             'showDeletedRecipes':self.show_deleted_recs,
             'emptyTrash':self.empty_trash,
             'on_timer': lambda *args: show_timer(),
+            'batch_edit':self.batch_edit_recs,
 #            'shopCatEditor': self.showShopEditor,            
             })
         # self.rc will be a list of open recipe cards.
@@ -198,6 +232,21 @@ class RecGui (RecIndex):
         self.update_splash(_("Done!"))
         self.threads = 0
 
+        gtkwindow.destroy()
+
+    def on_window_state_change(self, widget, event, *args):           
+        if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            self.window_in_fullscreen = True
+        else:
+            self.window_in_fullscreen = False
+
+    def on_key_press(self, widget, event, *args):            
+        if event.keyval == gtk.keysyms.F6:
+            if self.window_in_fullscreen:
+                self.app.unfullscreen()
+            else:
+                self.app.fullscreen()
+
     def search_entry_activate_cb (self, *args):
         if self.rmodel._get_length_()==1:
             self.recTreeSelectRec()
@@ -260,6 +309,7 @@ class RecGui (RecIndex):
     def show_about (self, *args):
         """Show information about ourselves, using GNOME's
         nice interface if available."""
+        import version
         debug("show_about (self, *args):",5)
         description=version.description
         copyright=version.copyright
@@ -328,7 +378,7 @@ class RecGui (RecIndex):
         else: name = ''
         for k,v in [('okay',True),
                     ('label',name),
-                    ('parent',self.app),
+                    ('parent',None),
                     ('pause',self.pause_cb),
                     ('stop',self.stop_cb),
                     ('modal',False),]:
@@ -362,7 +412,7 @@ class RecGui (RecIndex):
         debug("quit (self, *args):",5)
         for c in self.conf:
             c.save_properties()
-        a=self.glade.get_widget('app')
+        a=self.app
         for r in self.rc.values():
             for c in r.conf:
                 c.save_properties()
@@ -420,6 +470,7 @@ class RecGui (RecIndex):
         We load our recipe database from recipeManager. If there's any problem,
         we display the traceback to the user so they can send it out for debugging
         (or possibly make sense of it themselves!)."""
+        import gobject
         try:
             self.rd = recipeManager.RecipeManager(**recipeManager.dbargs)
             check_for_data_to_import(self.rd)
@@ -430,6 +481,7 @@ class RecGui (RecIndex):
             self.prefs['db_backend'] = None
             self.prefs.save()
             from StringIO import StringIO
+            import traceback
             f = StringIO()
             traceback.print_exc(file=f)
             error_mess = f.getvalue()
@@ -442,8 +494,11 @@ class RecGui (RecIndex):
         # connect hooks to modify our view whenever and
         # whenceever our recipes are updated...
         self.rd.modify_hooks.append(self.update_rec_iter)
+        self.rd.modify_hooks.append(self.updateAttributeModels)
+        self.rd.add_hooks.append(self.updateAttributeModels)
         #self.rd.add_hooks.append(self.new_rec_iter)
         self.rd.delete_hooks.append(self.delete_rec_iter)
+        self.rd.delete_hooks.append(self.updateAttributeModels)
         # a flag to make deleting multiple recs
         # more efficient...
         self.doing_multiple_deletions=False
@@ -458,6 +513,7 @@ class RecGui (RecIndex):
         # we'll need to hand these to various other places
         # that want a list of units.
         self.umodel = convertGui.UnitModel(self.conv)
+        self.attributeModels = []
         self.inginfo = reccard.IngInfo(self.rd)
         #self.create_rmodel(self.rd.rview)
         self.sl = shopgui.ShopGui(self, conv=self.conv)
@@ -528,6 +584,7 @@ class RecGui (RecIndex):
             self.del_rc(rec.id)
             
     def recTreeDeleteRecs (self, recs):
+        import string
         cancelled = []
         for rec in recs:
             if self.delete_open_card_carefully(rec): # returns True if user cancels
@@ -540,7 +597,9 @@ class RecGui (RecIndex):
             make_visible=lambda *args: self.redo_search()
             )
         self.set_reccount()
-        self.message(_("Deleted ") + string.join([r.title for r in recs],', '))
+        if hasattr(self,'recTrash'):
+            self.recTrash.update_from_db()
+        self.message(_("Deleted") + ' ' + string.join([(r.title or _('Untitled')) for r in recs],', '))
 
     def recTreePurge (self, recs, paths=None, model=None):
         if not use_threads and self.lock.locked_lock():
@@ -548,6 +607,9 @@ class RecGui (RecIndex):
                             sublabel=_('Please wait until it is finished to delete recipes.')
                             )
             return
+        if not recs:
+            # Do nothing if there are no recipes to delete.
+            return
         if not paths: paths=[]
         expander=None
         bigmsg = _("Permanently delete recipes?")
@@ -560,9 +622,10 @@ class RecGui (RecIndex):
                 msg += "\n<i>%s</i>"%r.title
         else:
             msg = _("Are you sure you want to delete the %s selected recipes?")%len(recs)
+            import treeview_extras as te
             tree = te.QuickTree([r.title for r in recs])
             expander = [_("See recipes"),tree]
-        if de.getBoolean(parent=self.app,label=bigmsg,sublabel=msg,expander=expander):
+        if de.getBoolean(parent=None,label=bigmsg,sublabel=msg,expander=expander):
             self.redo_search() # update all
 
             def show_progress (t):
@@ -632,6 +695,7 @@ class RecGui (RecIndex):
         return None
 
     def email_recs (self, *args):
+        import exporters.recipe_emailer as recipe_emailer
         debug('email_recs called!',1)
         recs = self.recTreeSelectedRecs()
         d=recipe_emailer.EmailerDialog(recs, self.rd, self.prefs, self.conv)
@@ -647,17 +711,18 @@ class RecGui (RecIndex):
             self.recTrash = RecTrash(self.rd,self.rg)
         else:
             self.recTrash.show()
+            
 
     def empty_trash (self, *args):
-        recs = self.rd.rview.select(deleted=True)
-        self.rg.recTreePurge(recs)
-        if hasattr(self,'recTrash'):
-            self.recTrash.rmodel.update_tree()
+        self.recTreePurge(
+            self.rd.fetch_all(self.rd.rview,deleted=True)
+            )
 
     def print_recs (self, *args):
         debug('printing recipes',3)
         recs = self.recTreeSelectedRecs()
         gt.gtk_leave()
+        import exporters.printer as printer
         printer.RecRenderer(self.rd, recs,
                             dialog_title=gettext.ngettext('Print %s recipe',
                                                           'Print %s recipes',
@@ -676,6 +741,7 @@ class RecGui (RecIndex):
             return True
 
     def newRecCard (self, *args):
+        import gobject
         self.app.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
         def show ():
             rc=reccard.RecCard(self)
@@ -689,6 +755,7 @@ class RecGui (RecIndex):
             self.rc[rec.id].updateAttribute(attribute,value)
 
     def openRecCard (self, rec):
+        import gobject
         if self.rc.has_key(rec.id):
             self.rc[rec.id].show()
         else:
@@ -721,7 +788,7 @@ class RecGui (RecIndex):
                     return
             else:
                 mult = de.getNumber(default=float(1),
-                                    label=_("Multiply %s by: ")%r.title,
+                                    label=_("Multiply %s by:")%r.title,
                                     parent=self.app.get_toplevel(),
                                     digits=2)
                 if not mult:
@@ -741,6 +808,7 @@ class RecGui (RecIndex):
     def save (self, file=None, db=None, xml=None):
         debug("save (self, file=None, db=None, xml=None):",5)
         if file and not xml and not db:
+            import re
             if re.search(".xml$",file):
                 xml=file
             else:
@@ -753,6 +821,7 @@ class RecGui (RecIndex):
             self.message(_("Saved!"))
             
     def message (self, msg):
+        import gobject
         debug("message (self, msg): %s"%msg,5)
         self.stat.push(self.contid,msg)
         gobject.timeout_add(1500,self.flush_messages)
@@ -775,14 +844,17 @@ class RecGui (RecIndex):
             cancel=False):
             self.rg.rd.clear_remembered_optional_ings() #without an arg, this clears all.
 
-    def export_selected_recs (self, *args): self.exportg(export_all=False)
-    def export_all_recs (self, *args): self.exportg(export_all=True)
+    def export_selected_recs (self, *args): 
+        self.exportg(export_all=False)
+
+    def export_all_recs (self, *args): 
+        self.exportg(export_all=True)
 
     def exportg (self, export_all=False):
         """If all is false, export only selected recipes.
 
         If all is True, export all recipes.
-        """
+        """	
         if not use_threads and self.lock.locked_lock():
             de.show_message(
                 parent=self.app.get_toplevel(),
@@ -790,6 +862,7 @@ class RecGui (RecIndex):
                 sublabel=_('Please wait until it is finished to start your export.')
                             )
             return
+        import exporters
         saveas_filters = exporters.saveas_filters[0:]
         ext = self.prefs.get('save_recipes_as','%sxml'%os.path.extsep)
         exp_directory = self.prefs.get('rec_exp_directory','~')
@@ -804,14 +877,20 @@ class RecGui (RecIndex):
             post_hooks = [self.after_dialog_offer_url(exp_type,file)]
             if exporters.exporter_dict.has_key(exp_type):
                 myexp = exporters.exporter_dict[exp_type]
+                if myexp.has_key('extra_prefs_dialog'):
+                    extra_prefs = myexp['extra_prefs_dialog']()
+                else:
+                    extra_prefs = {}
                 pd_args={'label':myexp['label'],'sublabel':myexp['sublabel']%{'file':file}}
-                if export_all: recs = self.rd.fetch_all(self.rd.rview,deleted=False)
+                if export_all: recs = self.rd.fetch_all(self.rd.rview,deleted=False,sort_by=[('title',1)])
                 else: recs = self.recTreeSelectedRecs()
                 expClass = myexp['mult_exporter']({'rd':self.rd,
                                                    'rv': recs,
                                                    'conv':self.conv,
                                                    'prog':self.set_progress_thr,
-                                                   'file':file})
+                                                   'file':file,
+                                                   'extra_prefs':extra_prefs,
+                                                   })
             if expClass:
                 self.threads += 1
                 def show_progress (t):
@@ -857,10 +936,11 @@ class RecGui (RecIndex):
                             )
             return
         import importers.html_importer
+        from zipfile import BadZipfile
         sublabel = _('Enter the URL of a recipe archive or recipe website.')
         url = de.getEntry(label=_('Enter website address.'),
                           sublabel=sublabel,
-                          entryLabel=_('Enter URL: '),
+                          entryLabel=_('Enter URL:'),
                           entryTip=_('Enter the address of a website or recipe archive. The address should begin with http://'),
                           default_character_width=60,
                           )
@@ -925,6 +1005,7 @@ class RecGui (RecIndex):
                             sublabel=_('Please wait until it is finished to start your import.')
                             )
             return
+        import importers
         import_directory = "%s/"%self.prefs.get('rec_import_directory',None)
         debug('show import dialog',0)
         ifiles=de.select_file(
@@ -932,7 +1013,8 @@ class RecGui (RecIndex):
             filename=import_directory,
             filters=importers.FILTERS,
             action=gtk.FILE_CHOOSER_ACTION_OPEN,
-            select_multiple=True)
+            select_multiple=True,
+            parent=self.app)
         if ifiles:
             self.prefs['rec_import_directory']=os.path.split(ifiles[0])[0]
             self.import_multiple_files(ifiles)
@@ -976,6 +1058,7 @@ class RecGui (RecIndex):
                             # about details later (this is stupid, but I'm sick of
                             # tracking down places where I e.g. closed files regardless
                             # of whether I opened them)
+                            import tempfile
                             finame=tempfile.mktemp(a.name)
                             tfi=open(finame,'w')
                             tfi.write(a.read())
@@ -987,6 +1070,7 @@ class RecGui (RecIndex):
                     raise
                     continue
             try:
+                import importers
                 impfilt = importers.FILTER_INFO[importers.select_import_filter(fn)]
             except NotImplementedError:
                 cant_import.append(fn)
@@ -999,7 +1083,7 @@ class RecGui (RecIndex):
                 if type(fn)==str: fname = fn
                 else: fname = "file"
                 source=de.getEntry(label=_("Default source for recipes imported from %s")%fname,
-                                   entryLabel=_('Source: '),
+                                   entryLabel=_('Source:'),
                                    default=os.path.split(fname)[1], parent=self.app)
                 # the 'get_source' dict is the kwarg that gets
                 # set to the source
@@ -1008,6 +1092,7 @@ class RecGui (RecIndex):
             else:
                 debug('GOURMET cannot import file %s'%fn)
         if importerClasses:
+            import importers
             impClass = importers.importer.MultipleImporter(self,
                                                            importerClasses)
             return impClass,cant_import
@@ -1018,6 +1103,7 @@ class RecGui (RecIndex):
         """Import multiple files,  showing dialog."""
         # This should probably be moved to importer with a quiet/not quiet options
         # and all of the necessary connections handed as arguments.
+        import string
         impClass,cant_import=self.prepare_import_classes(files)
         if impClass:
             filenames = filter(lambda x: isinstance(x,str), files)
@@ -1090,16 +1176,18 @@ class RecGui (RecIndex):
         debug('hooks: %s'%self.rd.add_hooks,1)
         self.wait_to_filter=False
         gt.gtk_enter()
+        self.updateAttributeModels()
         self.redo_search()
         gt.gtk_leave()
 
     def after_dialog_offer_url (self, linktype, file):
+        import exporters
         url = "file:///%s"%file
         label = _("Export succeeded")
         if linktype == exporters.WEBPAGE:
             url += '/index.htm'
             linktype = _("webpage")
-        sublabel = _("Exported %s to %s"%(linktype,file))
+        sublabel = _("Exported %s to %s")%(linktype,file)
         def offerer (t):
             if t.completed:
                 #self.idle_offer_url(label, sublabel, url, True)
@@ -1107,6 +1195,7 @@ class RecGui (RecIndex):
         return offerer
 
     def idle_offer_url (self, label, sublabl, url, from_thread):
+        import gobject
         if from_thread:
             gt.gtk_enter()
         gobject.idle_add(lambda *args: self.offer_url(label,sublabl,url,True))
@@ -1131,6 +1220,7 @@ class RecGui (RecIndex):
             gt.gtk_leave()
 
     def pause_cb (self, button, *args):
+        import gobject
         if button.get_active():
             debug('Suspending thread from pause_cb',0)
             self.thread.suspend()
@@ -1200,8 +1290,120 @@ class RecGui (RecIndex):
         cg=convertGui.ConvGui(converter=self.conv, unitModel=self.umodel)
 
     def showKeyEditor (self, *args):
+        import KeyEditor
         ke=keyEditor.KeyEditor(rd=self.rd, rg=self)
 
+    def showValueEditor (self, *args):
+        if not hasattr(self,'ve'):
+            import valueEditor
+            self.ve=valueEditor.ValueEditor(self.rd,self)
+        self.ve.valueDialog.connect('response',lambda d,r: (r==gtk.RESPONSE_APPLY and self.updateAttributeModels))
+        self.ve.show()
+
+
+    def batch_edit_recs (self, *args):
+        recs = self.recTreeSelectedRecs()
+        if not hasattr(self,'batchEditor'):
+            import batchEditor
+            self.batchEditor =  batchEditor.BatchEditor(self)
+        self.batchEditor.set_values_from_recipe(recs[0])
+        self.batchEditor.dialog.run()
+        # If we have values...
+        if self.batchEditor.values:
+            changes = self.batchEditor.values
+            only_where_blank = self.batchEditor.setFieldWhereBlank
+            attributes = ', '.join(changes.keys())
+            msg = gettext.ngettext('Set %(attributes)s for %(num)s selected recipe?',
+                                   'Set %(attributes)s for %(num)s selected recipes?',
+                                   len(recs))%{'attributes':attributes,
+                                               'num':len(recs),
+                                               }
+            msg += '\n'
+            if only_where_blank:
+                msg += _('Any previously existing values will not be changed.')+'\n'
+            else:
+                msg += _('The new values will overwrite any previously existing values.')+'\n'
+            msg += '<i>'+_('This change cannot be undone.')+'</i>'
+            if de.getBoolean(label=_('Set values for selected recipes'),sublabel=msg,cancel=False,
+                             custom_yes=gtk.STOCK_OK,custom_no=gtk.STOCK_CANCEL,):
+                for r in recs:
+                    if only_where_blank:
+                        changes = self.batchEditor.values.copy()
+                        for attribute in changes.keys():
+                            if hasattr(r,attribute) and getattr(r,attribute):
+                                del changes[attribute]
+                        if changes:
+                            self.rd.modify_rec(r,changes)
+                    else:
+                        self.rd.modify_rec(r,self.batchEditor.values)
+                    self.update_rec_iter(r)
+            else:
+                print 'Cancelled'
+        self.batchEditor.dialog.hide()
+        self.updateAttributeModels()
+                    
+    def getAttributeModel (self, attribute):
+        """Return a ListModel with a unique list of values for attribute.
+
+        This is stored here so that all the different comboboxes that
+        might need e.g. a list of categories can share 1 model and
+        save memory.
+        """
+        if not hasattr(self,'%sModel'%attribute):
+            slist = self.createAttributeList(attribute)
+            m = gtk.ListStore(str)
+            for i in slist: m.append([i])
+            setattr(self,'%sModel'%attribute,m)
+            self.attributeModels.append((attribute,getattr(self,'%sModel'%attribute)))
+        return getattr(self,'%sModel'%attribute)
+
+    def updateAttributeModels (self):
+        print 'updateAttributeModels!'
+        for attr,mod in self.attributeModels:
+            self.updateAttributeModel(attr)
+            
+    def updateAttributeModel (self, attribute):
+        slist = self.createAttributeList(attribute)
+        model = getattr(self,'%sModel'%attribute)
+        for n,item in enumerate(slist):
+            if model[n][0] == item:
+                continue
+            else:
+                # See if we match something later in the model -- if
+                # we do, suck up the whole model
+                additional = 1
+                found_match = False
+                while len(model) > (n+additional):
+                    if model[n+additional][0] == item:
+                        while additional > 0:
+                            model.remove(model.get_iter(n))
+                            additional -= 1
+                            found_match = False
+                        break
+                    additional += 1
+                if not found_match:
+                    model.insert(n,[item])
+        while len(model) > len(slist):
+            last = model.get_iter(len(model) - 1)
+            model.remove(last)
+        return model
+
+    def createAttributeList (self, attribute):
+        """Create a ListModel with unique values of attribute.
+        """
+        if attribute=='category':
+            slist = self.rg.rd.get_unique_values(attribute,self.rg.rd.catview)
+        else:
+            slist = self.rg.rd.get_unique_values(attribute,deleted=False)
+        if not slist:
+            slist = self.rg.rd.get_default_values(attribute)
+        else:
+            for default_value in self.rg.rd.get_default_values(attribute):
+                if default_value not in slist: slist.append(default_value)
+        slist.sort()
+        return slist
+
+    # END class RecGUI
 
 class RecTrash (RecIndex):
 
@@ -1234,13 +1436,20 @@ class RecTrash (RecIndex):
         return True
     
     def show (self, *args, **kwargs):
-        self.rmodel.update_tree()
         self.window.show(*args,**kwargs)
 
     def setup_search_views (self):
         self.last_search = ["",""]
         self.rvw = self.rd.fetch_all(self.rd.rview,deleted=True)
         self.searches = self.default_searches
+        self.sort_by = []
+
+    def update_from_db (self):
+        print 'UDPATE TRASH FROM DB!'
+        self.update_rmodel(self.rg.rd.fetch_all(
+            self.rg.rd.rview,deleted=True
+            )
+                                  )
 
     def recTreeUndeleteSelectedRecs (self, *args):
         mod,rr = self.rectree.get_selection().get_selected_rows()
@@ -1250,7 +1459,7 @@ class RecTrash (RecIndex):
             msg += r.title + ', '
             self.rg.rd.modify_rec(r,{'deleted':False})
         if msg: msg = msg[0:-2] # cut off the last comma
-        self.rmodel.update_tree()
+        self.update_from_db()
         self.rg.redo_search()
         self.rg.message(_('Undeleted recipes ') + msg)
 
@@ -1266,31 +1475,32 @@ class RecTrash (RecIndex):
         mod,rr=sel.get_selected_rows()
         recs = map(lambda path: mod[path][0],rr)
         self.rg.recTreePurge(recs,rr,mod)
+        self.update_from_db()
 
-def set_accel_paths (glade, widgets, base='<main>'):
-    """A convenience function. Hand us a function and set accel
-    paths based on it."""
-    for s in widgets:
-        w=glade.get_widget(s)
-        if type(w) == gtk.MenuItem: set_path_for_menuitem(w)
-        else:
-            for c in w.get_children():
-                if type(c) == gtk.MenuItem:
-                    set_path_for_menuitem(c,base)
-                else:
-                    debug("Can't handle %s"%c,1)
+#def set_accel_paths (glade, widgets, base='<main>'):
+#    """A convenience function. Hand us a function and set accel
+#    paths based on it."""
+#    for s in widgets:
+#        w=glade.get_widget(s)
+#        if type(w) == gtk.MenuItem: set_path_for_menuitem(w)
+#        else:
+#            for c in w.get_children():
+#                if type(c) == gtk.MenuItem:
+#                    set_path_for_menuitem(c,base)
+#                else:
+#                    debug("Can't handle %s"%c,1)
 
-def set_path_for_menuitem (mi, base='<main>'):
-    if mi.get_children():
-        accelLab = mi.get_children()[0]
-        l=accelLab.get_label().replace('_','')
-        path = base + '/' + l
-        mi.set_accel_path(path)
-    sm = mi.get_submenu()
-    if sm:
-        sm.set_accel_path(path)
-        for c in sm.get_children():
-            set_path_for_menuitem(c,path)
+#def set_path_for_menuitem (mi, base='<main>'):
+#    if mi.get_children():
+#        accelLab = mi.get_children()[0]
+#        l=accelLab.get_label().replace('_','')
+#        path = base + '/' + l
+#        mi.set_accel_path(path)
+#    sm = mi.get_submenu()
+#    if sm:
+#        sm.set_accel_path(path)
+#        for c in sm.get_children():
+#            set_path_for_menuitem(c,path)
     
 def startGUI ():
     debug("startGUI ():",4)
@@ -1298,7 +1508,7 @@ def startGUI ():
     debug("showing splash screen...",1)    
     gt.gtk_threads_init()
     #gtk.threads_init()
-    splash = gtk.Window()
+    splash = gtk.Window(gtk.WINDOW_POPUP)
     #splash.window_set_auto_startup_notification(False)
     splash.set_property('decorated',False)
     splash.set_position(gtk.WIN_POS_CENTER)
@@ -1327,6 +1537,7 @@ def startGUI ():
     splash.show()
     splash.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
     gt.gtk_enter()
+    #gtk.threads_enter()
     while gtk.events_pending():
         # show our GUI
         gtk.main_iteration()
@@ -1341,6 +1552,7 @@ def startGUI ():
     debug('hiding splash screen.',1)
     splash.hide()
     gtk.main()
+    #gtk.threads_leave()
     gt.gtk_leave()
               
 if __name__ == '__main__':
@@ -1352,8 +1564,7 @@ if __name__ == '__main__':
         prof.runcall(startGUI)
         stats = hotshot.stats.load(os.path.join(tempfile.tempdir,'GOURMET_HOTSHOT_PROFILE'))
         stats.strip_dirs()
-        stats.sort_stats('time','calls')
-        stats.print_stats()
+        stats.sort_stats('time','calls').print_stats()
         #profile.run('startGUI()',profi)
         #import pstats
         #p=pstats.Stats(profi)
