@@ -34,7 +34,7 @@ fields={'cuisine': ['American','Italian','Mexican',
                     'Southwestern','Asian/Thai','Asian/Vietnamese',
                     'Asian/Chinese','Asian/Japanese',],
         'rating' : ['Excellent','Great','Good','Fair','Poor'],
-        'source' : ['Epicurious'],
+        'source' : [],
         'category' : ['Dessert','Entree','Salad','Soup',
                       'Breakfast'],
                   }
@@ -534,11 +534,12 @@ INGREDIENT_DATA = [["alfalfa sprouts","alfalfa sprouts","produce"],
                    ['smoked cheese Gouda','cheese, smoked Gouda', 'dairy',],
                    ['lime juice','lime juice', 'produce',],
                    ['coconut milk','coconut milk', 'international',],
-                   ['eggs','eggs', 'dairy',],
+                   ['eggs','egg', 'dairy',],
                    ['salmon','salmon', 'seafood',],
                    ['lasagna pasta noodles','pasta, lasagna noodles', 'pastas',],
                    ['all purpose flour','flour, all purpose', 'baking',],
                    ['flour','flour, all purpose','baking',],
+                   ['all-purpose flour','flour, all purpose','baking',],
                    ['ground cumin','cumin, ground', 'spices',],
                    ['cucumber','cucumber', 'produce',],
                    ['salsa','salsa', 'international',],
@@ -571,9 +572,9 @@ INGREDIENT_DATA = [["alfalfa sprouts","alfalfa sprouts","produce"],
 # ("unit1","unit2"):conversion_factor, where unit1 contains conversion_factor X unit2
 # For example: 1 cup has 16 tablespoons.
 CONVERTER_TABLE = {
-    ("c.", "tbs."):16,
+    ("c.", "Tbs."):16,
     ("lb.", "oz."):16,
-    ("tbs.", "tsp."):3,
+    ("Tbs.", "tsp."):3,
     ("pt.", "c."):2,
     ("qt.", "c."):4,
     ("gallon", "qt."):4,
@@ -582,7 +583,7 @@ CONVERTER_TABLE = {
     ("l.", "cl."):100,
     ("l.", "dl."):10,
     ("oz.", "g."):28.35,
-    ("fl. oz.","tbs."):2,
+    ("fl. oz.","Tbs."):2,
     ("kg.", "g."):1000,
     ("g.", "mg."):1000,
     ("tsp.", "drop"):76,
@@ -644,8 +645,10 @@ UNITS = [["bucket" , ["bucket", "buckets", "bckt."]],
          ["grains", ["grain", "grains"]],
          ["dram", ["dram", "drams"]],
          ["drop",["drop"]],
+         ["fl oz",["fl oz","fluid ounce","fluid ounces","fl. oz.","fl oz.","fl. oz"]],
+         ['',['each','ea','ea.']],
          ["tsp.", ["teaspoon","tsp", "tsp.","tea spoon", "tsps.", "teaspoons", "tea spoons", "Teaspoon", "Teaspoons","t",'ts',"Ts.","Tsp.","Tsp"]],
-         ["tbs.", ["tablespoon","tbs", "tbsp", "tbs.", "tbsp.", "table spoon", "tbsps.", "tablespoons", "Tablespoon", "T",'tb',"Tbs.", "Tbsp", "Tbsp."]],
+         ["Tbs.", ["tablespoon","tbs", "tbsp", "tbs.", "tbsp.", "table spoon", "tbsps.", "tablespoons", "Tablespoon", "T",'tb',"Tbs.", "Tbsp", "Tbsp."]],
          ["lb.", [ "pound", "lb","lb.", "lbs.", "pounds"]],
          ["oz.", [ "ounce", "oz","ounces", "oz."]],
          ["c.", ["cup", "c.", "cups"]],
@@ -656,7 +659,7 @@ UNITS = [["bucket" , ["bucket", "buckets", "bckt."]],
          ["cl.", ["centiliter","cl", "cl.", "centiliters"]],
          ["dl.", ["deciliter","dl", "dl.","deciliters"]],
          ["l.", ["liter", "l.", "lit.", "liters",'l']],
-         ["g.", ["grams", "gram", "g.",'g']],
+         ["g.", ["grams", "gram", "g.",'g','gr','gr.']],
          ["mg.", ["miligram", "mg.", "mg", "miligrams"]],
          ["kg.", ["kilogram","kg.", "kg", "kilograms"]],
          # These names aren't really convertible, but we want them to
@@ -693,14 +696,16 @@ UNIT_GROUPS = {
                        ],
     'imperial volume':[('drop',(0,3)),
                        ('tsp.',(0.125,3)),
-                       ('tbs.',(1,4)),
+                       ('Tbs.',(1,4)),
                        ('c.',(0.25,6)),
                        ('pt.',(1,1)),
                        ('qt.',(1,3)),
                        ('gallon',(1,None)),
                        ('peck',(1,2)),
                        ('bucket',(1,2)),
-                       ('bushel',(1,None))]
+                       ('bushel',(1,None)),
+                       ('fl oz',(1,None)),
+                       ]
     }
 
 
@@ -716,7 +721,7 @@ CROSS_UNIT_TABLE = {
     ## up in the dictionary referenced here (i.e. the density_table)
     ## currently, 'density' is the only keyword used
     ("pt.", "lb."):['density',1],
-    ("tbs.", "oz."):['density',0.5],
+    ("Tbs.", "oz."):['density',0.5],
     ("c.", "oz."):['density',8],
     ("pt.", "oz."):['density',16],
     ("ml.", "g."):['density',1],
@@ -728,7 +733,7 @@ CROSS_UNIT_TABLE = {
 # assuming a density of 1 (i.e. the density of water).
 VOL_TO_MASS_TABLE = {
     ("pt.", "lb.") : 1,
-    ("tbs.", "oz.") : 0.5,
+    ("Tbs.", "oz.") : 0.5,
     ("c.", "oz.") : 8,
     ("pt.", "oz.") : 16,
     ("ml.", "g.") : 1,
@@ -789,7 +794,7 @@ NUMBERS = {
     (3.0/4):['three quarters'],
     (2.0/3):['two thirds'],
     (1.0/3):['third','a third'],
-    (1.0/2):['half','a half','one half'],
+    (1.0/2):['one half','a half','half'],
     1:['an','a','one'],
     2:['two','a couple','a couple of','a pair of'],
     3:['three'],
