@@ -1,3 +1,4 @@
+# -*- coding: UTF8 -*-
 ## we set up default information.
 
 ## first, easy to maintain lists which can eventually be moved to
@@ -9,7 +10,7 @@ fields={'cuisine': ['English','Scottish','Welsh','Irish','American',
                     'Southwestern','Asian/Thai','Asian/Vietnamese',
                     'Asian/Chinese','Asian/Japanese',],
         'rating' : ['Excellent','Great','Good','Fair','Poor'],
-        'source' : ['Epicurious'],
+        'source' : [],
         'category' : ['Dessert','Entree','Salad','Soup',
                       'Breakfast'],
                   }
@@ -466,7 +467,7 @@ INGREDIENT_DATA = [["alfalfa sprouts","alfalfa sprouts","produce"],
                    ['smoked cheese Gouda','cheese, smoked Gouda', 'dairy',],
                    ['lime juice','lime juice', 'produce',],
                    ['coconut milk','coconut milk', 'international',],
-                   ['eggs','eggs', 'dairy',],
+                   ['eggs','egg', 'dairy',],
                    ['salmon','salmon', 'seafood',],
                    ['lasagna pasta noodles','pasta, lasagna noodles', 'pastas',],
                    ['all flour purpose','flour, all purpose', 'baking',],
@@ -496,9 +497,9 @@ INGREDIENT_DATA = [["alfalfa sprouts","alfalfa sprouts","produce"],
                    ]
 
 CONVERTER_TABLE = {
-    ("c.", "tbs."):16,
+    ("c.", "Tbs."):16,
     ("lb.", "oz."):16,
-    ("tbs.", "tsp."):3,
+    ("Tbs.", "tsp."):3,
     ("pt.", "c."):2,
     ("qt.", "c."):4,
     ("gallon", "qt."):4,
@@ -555,7 +556,7 @@ UNITS = [["bucket" , ["bucket", "buckets", "bckt."]],
          ["dram", ["dram", "drams"]],
          ["drop",["drop"]],
          ["tsp.", ["teaspoon","tsp", "tsp.","tea spoon", "tsps.", "teaspoons", "tea spoons", "Teaspoon", "t"]],
-         ["tbs.", ["tablespoon","tbs", "tbsp", "tbs.", "tbsp.", "table spoon", "tbsps.", "tablespoons", "Tablespoon", "T"]],
+         ["Tbs.", ["tablespoon","tbs", "tbsp", "tbs.", "tbsp.", "table spoon", "tbsps.", "tablespoons", "Tablespoon", "T"]],
          ["lb.", [ "pound", "lb","lb.", "lbs.", "pounds"]],
          ["oz.", [ "ounce", "oz","ounces", "oz."]],
          ["c.", ["cup", "c.", "cups"]],
@@ -601,7 +602,7 @@ UNIT_GROUPS = {
                        ],
     'imperial volume':[('drop',(0,10)),
                        ('tsp.',(0.125,3)),
-                       ('tbs.',(1,4)),
+                       ('Tbs.',(1,4)),
                        ('c.',(0.25,4)),
                        ('pt.',(1,1)),
                        ('qt.',(1,3)),
@@ -621,14 +622,14 @@ CROSS_UNIT_TABLE = {
     ## up in the dictionary referenced here (i.e. the density_table)
     ## currently, 'density' is the only keyword used
     ("pt.", "lb."):['density',1],
-    ("tbs.", "oz."):['density',0.5],
+    ("Tbs.", "oz."):['density',0.5],
     ("c.", "oz."):['density',8],
     ("pt.", "oz."):['density',16],
     ("ml.", "g."):['density',1]}
 
 VOL_TO_MASS_TABLE = {
     ("pt.", "lb.") : 1,
-    ("tbs.", "oz.") : 0.5,
+    ("Tbs.", "oz.") : 0.5,
     ("c.", "oz.") : 8,
     ("pt.", "oz.") : 16,
     ("ml.", "g.") : 1,
