@@ -7,6 +7,7 @@ from gettext import gettext as _
 from gettext import ngettext
 import mnemonic_manager
 import pageable_store
+import hildon
 
 
 class KeyEditor:
@@ -19,7 +20,7 @@ class KeyEditor:
         self.glade = gtk.glade.XML(os.path.join(gglobals.gladebase,'keyeditor.glade'))        
         self.rd = rd
         self.rg = rg
-        self.widget_names = ['treeview', 'searchByBox', 'searchEntry', 'searchButton', 'window',
+        self.widget_names = ['treeview', 'searchByBox', 'searchEntry', 'searchButton',
                              'searchAsYouTypeToggle', 'regexpTog',
                              'changeKeyEntry',
                              'changeItemEntry',
@@ -34,6 +35,18 @@ class KeyEditor:
                         'unit':self.changeUnitEntry,
                         'amount':self.changeAmountEntry,
                         }
+
+        self.window = hildon.Window()
+        self.window.set_default_size(800, 480)
+        self.window.set_title('Key Editor')
+        self.window.connect("key-press-event", self.on_key_press)
+        self.window.connect("window-state-event", self.on_window_state_change)
+        self.window_in_fullscreen = False 
+
+        gtkwindow = self.glade.get_widget('window')
+        alignment15 = self.glade.get_widget('alignment15')
+        alignment15.reparent(self.window)
+
         # setup entry callback to sensitize/desensitize apply
         self.applyEntriesButton.set_sensitive(False)
         self.clearEntriesButton.set_sensitive(False)
@@ -90,6 +103,23 @@ class KeyEditor:
             self.rg.prefs.get('regexpTog',
                            {'active':self.regexpTog.get_active()}),
             ['toggled']))
+
+        gtkwindow.destroy()
+        self.window.show_all()
+
+    def on_window_state_change(self, widget, event, *args):           
+        if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            self.window_in_fullscreen = True
+        else:
+            self.window_in_fullscreen = False
+
+    def on_key_press(self, widget, event, *args):            
+        if event.keyval == gtk.keysyms.F6:
+            if self.window_in_fullscreen:
+                self.window.unfullscreen()
+            else:
+                self.window.fullscreen()
+
                 
     def dont_ask_cb (self, widget, *args):
         self.dont_ask=widget.get_active()
@@ -100,8 +130,6 @@ class KeyEditor:
         self.VALUE_COL = 2
         self.COUNT_COL = 3
         self.REC_COL = 4
-        cssu = pageable_store.ColumnSortSetterUpper(self.treeModel)
-        sortable = [self.VALUE_COL,self.COUNT_COL]
         for n,head in [[self.FIELD_COL,_('Field')],
                        [self.VALUE_COL,_('Value')],
                        [self.COUNT_COL,_('Count')],
@@ -113,7 +141,7 @@ class KeyEditor:
             col = gtk.TreeViewColumn(head, renderer, text=n)
             col.set_resizable(True)
             self.treeview.append_column(col)
-            if n in sortable: cssu.set_sort_column_id(col,n)
+
 
     def tree_edited (self, renderer, path_string, text, n, head):
         indices = path_string.split(':')
