@@ -12,6 +12,7 @@ import gourmet.WidgetSaver as WidgetSaver
 import re
 import os,os.path
 from gettext import gettext as _
+import hildon
 
 class SpecialAction:
 
@@ -131,8 +132,16 @@ class NutritionInfoDruid (gobject.GObject):
                                [self.ALL_GROUPS]+self.rd.get_unique_values('foodgroup',self.rd.nview)
                                )
         cb.cb_set_active_text(self.foodGroupComboBox,self.ALL_GROUPS)
+
+        self.window = hildon.Window()
+        self.window.set_default_size(800, 480)
+        self.window.set_title('Nutrition Editor')
+        self.window.connect("key-press-event", self.on_key_press)
+        self.window.connect("window-state-event", self.on_window_state_change)
+        self.window_in_fullscreen = False 
+
         # Save our position with our widget saver...
-        WidgetSaver.WindowSaver(self.glade.get_widget('window1'),
+        WidgetSaver.WindowSaver(self.window,
                                 self.prefs.get('nutritionDruid',{})
                                 )
         WidgetSaver.WidgetSaver(
@@ -141,6 +150,25 @@ class NutritionInfoDruid (gobject.GObject):
                            {'active':True}),
             ['toggled'])
 
+        gtkwindow = self.glade.get_widget('window1')
+        vbox2 = self.glade.get_widget('vbox2')
+        vbox2.reparent(self.window)
+
+        gtkwindow.destroy()
+
+    def on_window_state_change(self, widget, event, *args):           
+        if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            self.window_in_fullscreen = True
+        else:
+            self.window_in_fullscreen = False
+
+    def on_key_press(self, widget, event, *args):            
+        if event.keyval == gtk.keysyms.F6:
+            if self.window_in_fullscreen:
+                self.window.unfullscreen()
+            else:
+                self.window.fullscreen()
+
     # Setup functions
     def _setup_widgets_ (self):
         self.controls = []
@@ -612,7 +640,7 @@ class NutritionInfoDruid (gobject.GObject):
             self.goto_page_unit_convert()
 
     def finish (self):
-        self.glade.get_widget('window1').hide()
+        self.window.hide()
         print self,'EMIT: finish'
         self.emit('finish')
 
@@ -743,7 +771,7 @@ class NutritionInfoDruid (gobject.GObject):
         gobject.idle_add(self.search)
     
     def show (self):
-        self.glade.get_widget('window1').show()
+        self.window.show()
 
     #def notebook_page_changed_cb (self, *args):
     #    if self.notebook.get_current_page()==0: self.prevDruidButton.set_sensitive(False)
@@ -791,8 +819,8 @@ if __name__ == '__main__':
                          
     def quit (*args):
         rd.save()
-        nid.glade.get_widget('window1').hide()
+        nid.window.hide()
         gtk.main_quit()
-    nid.glade.get_widget('window1').connect('delete-event',quit)
+    nid.window.connect('delete-event',quit)
     nid.connect('finish',quit)
     gtk.main()
